@@ -7,15 +7,11 @@
 #include "classes.h"
 
 namespace MiX{
-  /**
-   * DOMɎsɓO\NX
-   *
-   * G[Nm[hɑ΂
-   */
-  template <class charT,class traitsT>
+
+  template <class charT,class char_traits,class xml_traits>
   class DOM_Exception : public std::exception{
   public:
-    MiX_Template_Typedef(charT,traitsT);
+    MiX_Template_Typedef(charT,char_traits,xml_traits);
   private:
     const node_type* node_;
     ErrorType type_;
